@@ -49,7 +49,7 @@ class BurnCommand(PluginCommand):
                        [--bs=BLOCKSIZE]
                        [--dryrun]
                        [--no_diagram]
-              burn ubuntu NAMES [--inventory=INVENTORY] [--ssid=SSID]
+              burn ubuntu NAMES [--inventory=INVENTORY] [--ssid=SSID] [-f]
               [--wifipassword=PSK] [-v] --device=DEVICE [--country=COUNTRY]
               [--upgrade]
               burn raspberry NAMES --device=DEVICE
@@ -60,7 +60,6 @@ class BurnCommand(PluginCommand):
                                   [--password=PASSWORD]
                                   [-v]
                                   [-f]
-              [--timezone=TIMEZONE]
               burn firmware check
               burn firmware update
               burn install
@@ -434,14 +433,19 @@ class BurnCommand(PluginCommand):
             wifipasswd = arguments['--wifipassword']
 
             if arguments.inventory:
-                burner = RaspberryBurner(inventory=arguments.inventory)
+                inv_path = path_expand(f'~/.cloudmesh/{arguments.inventory}.yaml')
+                try:
+                    burner = RaspberryBurner(inventory=inv_path)
+                except:
+                    Console.error('Burner Error')
+                    return ""
             else:
                 if workers:
                     worker_base_name = ''.join(
                         [i for i in workers[0] if not i.isdigit()])
 
                 cluster_name = manager or worker_base_name
-                inventory = path_expand(f'~/.cloudmesh/inventory-{cluster_name}.yml')
+                inventory = path_expand(f'~/.cloudmesh/inventory-{cluster_name}.yaml')
 
                 if not os.path.exists(inventory) or arguments['-f']:
                     if not manager:
@@ -453,7 +457,11 @@ class BurnCommand(PluginCommand):
                     _build_default_inventory(filename=inventory,
                                              manager=manager, workers=workers)
 
-                burner = RaspberryBurner(inventory=inventory)
+                try:
+                    burner = RaspberryBurner(inventory=inventory)
+                except:
+                    Console.error('Burner Error')
+                    return ""
 
                 if manager:
                     if not ssid:
@@ -461,7 +469,8 @@ class BurnCommand(PluginCommand):
                         if ssid == "":
                             Console.info('Could not determine SSID, skipping wifi '
                                          'config')
-                    if not wifipasswd and not ssid == "":
+                            ssid = None
+                    if not wifipasswd and not ssid is None:
                         wifipasswd = getpass(f"Using --SSID={ssid}, please "
                                              f"enter wifi password:")
 
@@ -487,8 +496,45 @@ class BurnCommand(PluginCommand):
                 c = Configure(inventory=arguments.inventory, debug=arguments['-v'])
                 inv = Inventory(filename=arguments.inventory)
             else:
-                c = Configure(debug=arguments['-v'])
-                inv = Inventory()
+                names = Parameter.expand(arguments.NAMES)
+                manager, workers = Host.get_hostnames(names)
+                if workers:
+                    worker_base_name = ''.join(
+                        [i for i in workers[0] if not i.isdigit()])
+
+                cluster_name = manager or worker_base_name
+                inventory = path_expand(f'~/.cloudmesh/inventory-{cluster_name}.yaml')
+
+                if not os.path.exists(inventory) or arguments['-f']:
+                    if not manager:
+                        Console.error("No inventory found. Can not create an "
+                                      "inventory without a "
+                                      "manager.")
+                        return ""
+
+                    _build_default_inventory(filename=inventory,
+                                             manager=manager,
+                                             workers=workers,
+                                             manager_image='ubuntu-20.10-64-bit',
+                                             worker_image='ubuntu-20.10-64-bit')
+
+                c = Configure(inventory = inventory, debug=arguments['-v'])
+                inv = Inventory(filename=inventory)
+
+                if manager:
+                    if not arguments.ssid:
+                        arguments.ssid = get_ssid()
+                        if arguments.ssid == "":
+                            Console.info('Could not determine SSID, skipping wifi '
+                                         'config')
+                            arguments.ssid = None
+                    if not arguments.wifipassword and not arguments.ssid is None:
+                        arguments.country = Shell.locale().upper()
+                        arguments.wifipassword = getpass(f"Using --SSID="
+                                                       f"{arguments.ssid} and "
+                                                       f" --COUNTRY="
+                                                       f"{arguments.country}, please "
+                                                       f"enter wifi password:")
 
             # Probably not the best way to get the tag, but we assume all tags
             # are the same for each row for now
@@ -1003,7 +1049,9 @@ class BurnCommand(PluginCommand):
         return ""
 
 
-def _build_default_inventory(filename, manager, workers, ips=None, images=None):
+def _build_default_inventory(filename, manager, workers, ips=None,
+                             manager_image='latest-lite',
+                             worker_image='latest-lite'):
     # cms inventory add red --service=manager --ip=10.1.1.1 --tag=latest-lite
     # --timezone="America/Indiana/Indianapolis" --locale="us"
     # cms inventory set red services to "bridge" --listvalue
@@ -1019,7 +1067,7 @@ def _build_default_inventory(filename, manager, workers, ips=None, images=None):
     timezone = Shell.timezone()
     locale = Shell.locale()
     manager_ip = ips[0] if ips else '10.1.1.1'
-    image = images[0] if images else 'latest-lite'
+    image = manager_image
     element = {}
     element['host'] = manager
     element['status'] = 'inactive'
@@ -1035,23 +1083,25 @@ def _build_default_inventory(filename, manager, workers, ips=None, images=None):
 
     last_octet = 2
     index = 1
-    for worker in workers:
-        ip = ips[index] if ips else f'10.1.1.{last_octet}'
-        image = images[index] if images else 'latest-lite'
-        element = {}
-        element['host'] = worker
-        element['status'] = 'inactive'
-        element['service'] = 'worker'
-        element['ip'] = ip
-        element['tag'] = image
-        element['timezone'] = timezone
-        element['locale'] = locale
-        element['router'] = manager_ip
-        element['dns'] = ['8.8.8.8', '8.8.4.4']
-        element['keyfile'] = '~/.ssh/id_rsa.pub'
-        i.add(**element)
-        i.save()
-        last_octet += 1
-        index += 1
+    if workers is not None:
+        for worker in workers:
+            ip = ips[index] if ips else f'10.1.1.{last_octet}'
+            image = worker_image
+            element = {}
+            element['host'] = worker
+            element['status'] = 'inactive'
+            element['service'] = 'worker'
+            element['ip'] = ip
+            element['tag'] = image
+            element['timezone'] = timezone
+            element['locale'] = locale
+            element['router'] = manager_ip
+            element['dns'] = ['8.8.8.8', '8.8.4.4']
+            element['keyfile'] = '~/.ssh/id_rsa.pub'
+            i.add(**element)
+            i.save()
+            last_octet += 1
+            index += 1
 
+    i.save()
     print(i.list(format="table"))
